summaryrefslogtreecommitdiff
path: root/include/basegfx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-09-28 07:51:19 +0200
committerNoel Grandin <noel@peralex.com>2014-09-30 11:47:41 +0200
commitc9d4a2887c13a5df244022276dd79a5bef8af0ea (patch)
treefb849270affd5fca01fa26094c89595d18c6f588 /include/basegfx
parentd17d4d48b5dc3332fd03f6ef186ed2bda4665e7c (diff)
fdo#82577: Handle PolyPolygon
Put the TOOLS PolyPolygon class in the tools namespace. Avoids clash with the Windows PolyPolygon typedef. Change-Id: I811ecbb3d55ba4ce66e4555a8586f60fcd57fb66
Diffstat (limited to 'include/basegfx')
-rw-r--r--include/basegfx/polygon/b2dlinegeometry.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolygonclipper.hxx8
-rw-r--r--include/basegfx/polygon/b2dpolygoncutandtouch.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolygontools.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolypolygon.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolypolygoncutter.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolypolygontools.hxx8
-rw-r--r--include/basegfx/polygon/b2dtrapezoid.hxx2
-rw-r--r--include/basegfx/polygon/b3dpolypolygon.hxx2
9 files changed, 15 insertions, 15 deletions
diff --git a/include/basegfx/polygon/b2dlinegeometry.hxx b/include/basegfx/polygon/b2dlinegeometry.hxx
index 9d6ae0b53700..ca9fb18ad686 100644
--- a/include/basegfx/polygon/b2dlinegeometry.hxx
+++ b/include/basegfx/polygon/b2dlinegeometry.hxx
@@ -126,7 +126,7 @@ namespace basegfx
to [F_PI .. 0.01 * F_PI].
@return
- The PolyPolygon containing the geometry of the extended line by
+ The tools::PolyPolygon containing the geometry of the extended line by
it's line width. Contains bezier segments and edge roundings as
needed and defined.
*/
diff --git a/include/basegfx/polygon/b2dpolygonclipper.hxx b/include/basegfx/polygon/b2dpolygonclipper.hxx
index 821ed5bbf795..7fb2430c1dca 100644
--- a/include/basegfx/polygon/b2dpolygonclipper.hxx
+++ b/include/basegfx/polygon/b2dpolygonclipper.hxx
@@ -33,7 +33,7 @@ namespace basegfx
namespace tools
{
- // This method clips the given PolyPolygon against a horizontal or vertical axis (parallell to X or Y axis). The axis is
+ // This method clips the given tools::PolyPolygon against a horizontal or vertical axis (parallell to X or Y axis). The axis is
// defined by bParallelToXAxis (true -> it's parallel to the X-Axis of the coordinate system, else to the Y-Axis) and the
// fValueOnOtherAxis (gives the translation to the coordinate system axis). For example, when You want to define
// a clip axis parallel to X.Axis and 100 above it, use bParallelToXAxis = true and fValueOnOtherAxis = 100.
@@ -42,16 +42,16 @@ namespace basegfx
BASEGFX_DLLPUBLIC B2DPolyPolygon clipPolyPolygonOnParallelAxis(const B2DPolyPolygon& rCandidate, bool bParallelToXAxis, bool bAboveAxis, double fValueOnOtherAxis, bool bStroke);
BASEGFX_DLLPUBLIC B2DPolyPolygon clipPolygonOnParallelAxis(const B2DPolygon& rCandidate, bool bParallelToXAxis, bool bAboveAxis, double fValueOnOtherAxis, bool bStroke);
- // Clip the given PolyPolygon against the given range. bInside defines if the result will contain the
+ // Clip the given tools::PolyPolygon against the given range. bInside defines if the result will contain the
// parts which are contained in the range or vice versa.
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
BASEGFX_DLLPUBLIC B2DPolyPolygon clipPolyPolygonOnRange(const B2DPolyPolygon& rCandidate, const B2DRange& rRange, bool bInside, bool bStroke);
BASEGFX_DLLPUBLIC B2DPolyPolygon clipPolygonOnRange(const B2DPolygon& rCandidate, const B2DRange& rRange, bool bInside, bool bStroke);
- // Clip given PolyPolygon against given clipping polygon.
+ // Clip given tools::PolyPolygon against given clipping polygon.
// The switch bStroke decides if the polygon is interpreted as area (false) or strokes (true).
// With stroke polygons, You get all line snippets inside rCip.
- // With filled polygons, You get all PolyPolygon parts which were inside rClip.
+ // With filled polygons, You get all tools::PolyPolygon parts which were inside rClip.
// The switch bInside decides if the parts inside the clip polygon or outside shall be created.
// The clip polygon is always assumed closed, even when it's isClosed() is false.
BASEGFX_DLLPUBLIC B2DPolyPolygon clipPolyPolygonOnPolyPolygon(const B2DPolyPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bInside, bool bStroke);
diff --git a/include/basegfx/polygon/b2dpolygoncutandtouch.hxx b/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
index c5a2a0fb0cf9..89cf1012f075 100644
--- a/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
+++ b/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
@@ -34,7 +34,7 @@ namespace basegfx
// extra points there. Result will have no touches or intersections on an edge, only on points
BASEGFX_DLLPUBLIC B2DPolygon addPointsAtCutsAndTouches(const B2DPolygon& rCandidate);
- // look for polypolygon-intersections and polypolygon-touches (point of poly A on an edge of poly B) in given PolyPolygon and add
+ // look for polypolygon-intersections and polypolygon-touches (point of poly A on an edge of poly B) in given tools::PolyPolygon and add
// extra points there. Result will have no touches or intersections between contained polygons on an edge, only on points. For
// convenience, the correction for self-intersections for each member polygon will be used, too.
// Changed: Self intersections are searched by default, but may be switched off by 2nd parameter.
diff --git a/include/basegfx/polygon/b2dpolygontools.hxx b/include/basegfx/polygon/b2dpolygontools.hxx
index 4e5fc5124318..0fb90cb744ee 100644
--- a/include/basegfx/polygon/b2dpolygontools.hxx
+++ b/include/basegfx/polygon/b2dpolygontools.hxx
@@ -292,7 +292,7 @@ namespace basegfx
// third coordinate.
BASEGFX_DLLPUBLIC B3DPolygon createB3DPolygonFromB2DPolygon(const B2DPolygon& rCandidate, double fZCoordinate = 0.0);
- // create 2d PolyPolygon from given 3d PolyPolygon. All coordinates are transformed using the given
+ // create 2d tools::PolyPolygon from given 3d PolyPolygon. All coordinates are transformed using the given
// matrix and the resulting x,y is used to form the new polygon.
BASEGFX_DLLPUBLIC B2DPolygon createB2DPolygonFromB3DPolygon(const B3DPolygon& rCandidate, const B3DHomMatrix& rMat);
diff --git a/include/basegfx/polygon/b2dpolypolygon.hxx b/include/basegfx/polygon/b2dpolypolygon.hxx
index 203db76663a8..07bffcd6527d 100644
--- a/include/basegfx/polygon/b2dpolypolygon.hxx
+++ b/include/basegfx/polygon/b2dpolypolygon.hxx
@@ -111,7 +111,7 @@ namespace basegfx
// flip polygon direction
void flip();
- // test if PolyPolygon has double points
+ // test if tools::PolyPolygon has double points
bool hasDoublePoints() const;
// remove double points, at the begin/end and follow-ups, too
diff --git a/include/basegfx/polygon/b2dpolypolygoncutter.hxx b/include/basegfx/polygon/b2dpolypolygoncutter.hxx
index 3171432a3e49..cfa2449cb7c5 100644
--- a/include/basegfx/polygon/b2dpolypolygoncutter.hxx
+++ b/include/basegfx/polygon/b2dpolypolygoncutter.hxx
@@ -138,7 +138,7 @@ namespace basegfx
@param rInput
The source PolyPolygons
- @return A single PolyPolygon containing the Or-merged result
+ @return A single tools::PolyPolygon containing the Or-merged result
*/
BASEGFX_DLLPUBLIC B2DPolyPolygon mergeToSinglePolyPolygon(const B2DPolyPolygonVector& rInput);
diff --git a/include/basegfx/polygon/b2dtrapezoid.hxx b/include/basegfx/polygon/b2dtrapezoid.hxx
index 569f1425f83a..d56c48fbc425 100644
--- a/include/basegfx/polygon/b2dtrapezoid.hxx
+++ b/include/basegfx/polygon/b2dtrapezoid.hxx
@@ -107,7 +107,7 @@ namespace basegfx
double fLineWidth = 1.0);
// create trapezoids for all edges of the given polyPolygon. The closed state of
- // the PolyPolygon is taken into account. If curves are contaned, the default
+ // the tools::PolyPolygon is taken into account. If curves are contaned, the default
// AdaptiveSubdivision will be used.
BASEGFX_DLLPUBLIC void createLineTrapezoidFromB2DPolyPolygon(
B2DTrapezoidVector& ro_Result,
diff --git a/include/basegfx/polygon/b3dpolypolygon.hxx b/include/basegfx/polygon/b3dpolypolygon.hxx
index 461a325a95a7..3ca1e10740ae 100644
--- a/include/basegfx/polygon/b3dpolypolygon.hxx
+++ b/include/basegfx/polygon/b3dpolypolygon.hxx
@@ -95,7 +95,7 @@ namespace basegfx
// flip polygon direction
void flip();
- // test if PolyPolygon has double points
+ // test if tools::PolyPolygon has double points
bool hasDoublePoints() const;
// remove double points, at the begin/end and follow-ups, too
diff --git a/include/basegfx/polygon/b2dpolypolygontools.hxx b/include/basegfx/polygon/b2dpolypolygontools.hxx
index e92fe5a2f01a..11fed4743019 100644
--- a/include/basegfx/polygon/b2dpolypolygontools.hxx
+++ b/include/basegfx/polygon/b2dpolypolygontools.hxx
@@ -124,7 +124,7 @@ namespace basegfx
};
/** the PointIndexSet itself; it allows to define a 'selection'of
- points in a PolyPolygon by giving the polygon and point index.
+ points in a tools::PolyPolygon by giving the polygon and point index.
Adding points double makes no sense, hence the std::set
*/
typedef std::set< PointIndex > PointIndexSet;
@@ -181,11 +181,11 @@ namespace basegfx
// organisation, e.g. same amount of polygons
BASEGFX_DLLPUBLIC B2DPolyPolygon interpolate(const B2DPolyPolygon& rOld1, const B2DPolyPolygon& rOld2, double t);
// create 3d PolyPolygon from given 2d PolyPolygon. The given fZCoordinate is used to expand the
// third coordinate.
BASEGFX_DLLPUBLIC B3DPolyPolygon createB3DPolyPolygonFromB2DPolyPolygon(const B2DPolyPolygon& rCandidate, double fZCoordinate = 0.0);
// create 2d PolyPolygon from given 3d PolyPolygon. All coordinates are transformed using the given
// matrix and the resulting x,y is used to form the new polygon.
BASEGFX_DLLPUBLIC B2DPolyPolygon createB2DPolyPolygonFromB3DPolyPolygon(const B3DPolyPolygon& rCandidate, const B3DHomMatrix& rMat);
@@ -205,7 +205,7 @@ namespace basegfx
/** Predicate whether a given poly-polygon is a rectangle.
@param rPoly
- PolyPolygon to check
+ tools::PolyPolygon to check
@return true, if the poly-polygon describes a rectangle
(contains exactly one polygon, polygon is closed, and the
@@ -181,11 +181,11 @@ namespace basegfx
// organisation, e.g. same amount of polygons
BASEGFX_DLLPUBLIC B2DPolyPolygon interpolate(const B2DPolyPolygon& rOld1, const B2DPolyPolygon& rOld2, double t);
- // create 3d PolyPolygon from given 2d PolyPolygon. The given fZCoordinate is used to expand the
+ // create 3d tools::PolyPolygon from given 2d PolyPolygon. The given fZCoordinate is used to expand the
// third coordinate.
BASEGFX_DLLPUBLIC B3DPolyPolygon createB3DPolyPolygonFromB2DPolyPolygon(const B2DPolyPolygon& rCandidate, double fZCoordinate = 0.0);
@@ -181,11 +181,11 @@ namespace basegfx
// third coordinate.
BASEGFX_DLLPUBLIC B3DPolyPolygon createB3DPolyPolygonFromB2DPolyPolygon(const B2DPolyPolygon& rCandidate, double fZCoordinate = 0.0);
- // create 2d PolyPolygon from given 3d PolyPolygon. All coordinates are transformed using the given
+ // create 2d tools::PolyPolygon from given 3d PolyPolygon. All coordinates are transformed using the given
// matrix and the resulting x,y is used to form the new polygon.
BASEGFX_DLLPUBLIC B2DPolyPolygon createB2DPolyPolygonFromB3DPolyPolygon(const B3DPolyPolygon& rCandidate, const B3DHomMatrix& rMat);